[![Documentation Status](https://readthedocs.org/projects/neurokin/badge/?version=latest)](https://neurokin.readthedocs.io/en/latest/?badge=latest)

# neurokin

neurokin aims to simplify the import and processing of neural and kinematic data. On top of basic preprocessing functions, it also provides more complex pipelines for multimodal data analysis. 
neurokin supports open_ephys and TDT formats natively for neural and .c3d files and DeepLabCut datasets for kinematics data but can be expanded easily. Please get in touch if you have another type of data.

See the [documentation](https://neurokin.readthedocs.io/en/latest/) for example analysis


<p align="center">
  <img src="https://github.com/user-attachments/assets/0ac3c436-f3f8-4c6a-a689-e359dbbbe4cb" />
</p>
